@@ -431,7 +431,6 @@ class PgDatabase:
         sql_string = "CREATE SCHEMA {schema} AUTHORIZATION {user};".format(**self._settings)
         return self._execute_sql(sql_string=sql_string, get_result=False)
 
-
     def _test_table(self, table_name, table_columns, create, primary_key=None):
         func_name = f'{self.__class__.__name__}.{sys._getframe().f_code.co_name}()'
         err_str = f'Error in {func_name}'
@@ -618,7 +617,7 @@ class TasksDatabase:
                          'success_email': 'varchar',
                          'parent_task_id': 'int4',
                          }
-        if not TasksDatabase.pg_database._test_table(table_name, table_columns, create):
+        if not TasksDatabase.pg_database._test_table(table_name, table_columns, create, primary_key=['task_id']):
             print(f'{err_str}: Database.pg_database._test_table("{table_name}")')
             return False
         return True
