@@ -94,7 +94,7 @@ class Worker(object):
                     params = json.loads(params)
                     if not isinstance(params, dict):
                         params = dict()
-                    print(f'{func_name}: try to start "{task_module}.{task_func}"...')
+                    # print(f'{func_name}: try to start "{task_module}.{task_func}"...')
                     result = func(**params)
                 except Exception as e:
                     error = f'Error in {func_name}: {type(e)}: {str(e)}; traceback: {traceback.print_exc()}'
@@ -111,7 +111,7 @@ class Worker(object):
 
         try:
             task_dict = database.get_one_task()
-            print(f'{func_name}: now={datetime.datetime.now()}; task_dict: {task_dict}')
+            # print(f'{func_name}: now={datetime.datetime.now()}; task_dict: {task_dict}')
             if isinstance(task_dict, dict):
                 queue = multiprocessing.Queue()
                 worker = multiprocessing.Process(target=self.worker_process, args=(queue, task_dict,))
